@@ -1,5 +1,6 @@
 #!/usr/bin/env python
-# Copyright 2019-2020 CERN for the benefit of the ATLAS collaboration.
+# -*- coding: utf-8 -*-
+# Copyright 2019-2021 CERN
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,28 +18,23 @@
 # - Tomas Javurek <tomas.javurek@cern.ch>, 2019
 # - Boris Bauermeister <boris.bauermeister@fysik.su.se>, 2019
 # - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
-# - Martin Barisits <martin.barisits@cern.ch>, 2019
-# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
+# - Martin Barisits <martin.barisits@cern.ch>, 2019-2021
+# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020-2021
 
-import sys
-import os
 import errno
 import fcntl
-import time
 import getopt
+import os
 import re
-import subprocess
 import signal
-
-try:
-    # Python 2
-    from urllib import urlencode, urlopen
-except ImportError:
-    # Python 3
-    from urllib.parse import urlencode
-    from urllib.request import urlopen
+import subprocess
+import sys
+import time
 from socket import gethostname
 
+from six.moves.urllib.parse import urlencode
+from six.moves.urllib.request import urlopen
+
 # The pCache Version
 pcacheversion = "4.2.3"
 
@@ -723,9 +719,9 @@ class Pcache:
                  unitize(self.get_cache_size()),
                  self.get_disk_usage())
 
-        for l in self.list_by_mru():
+        for link in self.list_by_mru():
             try:
-                d = os.readlink(l)
+                d = os.readlink(link)
 
             except OSError as e:
                 self.log(ERROR, "readlink: %s", e)
@@ -745,7 +741,7 @@ class Pcache:
             # backlink
 
             try:
-                os.unlink(l)
+                os.unlink(link)
 
             except OSError as e:
                 if e.errno != errno.ENOENT:
