@@ -29,6 +29,7 @@
 # - Eli Chadwick, <eli.chadwick@stfc.ac.uk>, 2020
 # - Luca Scotto Lavina, <scotto@lpnhe.in2p3.fr>, 2021
 # - Thomas Beermann, <thomas.beermann@cern.ch>, 2021
+# - James Perry <j.perry@epcc.ed.ac.uk>, 2021
 #
 # PY3K COMPATIBLE
 
@@ -82,6 +83,7 @@ class RSEDeterministicTranslation(object):
         self.rse = rse
         self.rse_attributes = rse_attributes if rse_attributes else {}
         self.protocol_attributes = protocol_attributes if protocol_attributes else {}
+        self.loaded_policy_modules = False
 
     @classmethod
     def supports(cls, name):
@@ -228,6 +230,7 @@ class RSEDeterministicTranslation(object):
         cls.register(cls.__identity, "identity")
         cls.register(cls.__ligo, "ligo")
         cls.register(cls.__belleii, "belleii")
+        cls.register(cls.__xenon, "xenon")
         policy_module = None
         try:
             policy_module = config.config_get('policy', 'lfn2pfn_module')
@@ -241,6 +244,31 @@ class RSEDeterministicTranslation(object):
 
         cls._DEFAULT_LFN2PFN = config.get_lfn2pfn_algorithm_default()
 
+    def try_importing_policy(self, vo=None):
+        import importlib
+        try:
+            package = config.config_get('policy', 'package' + ('' if not vo else '-' + vo['vo']))
+            module = importlib.import_module(package)
+            if hasattr(module, 'get_lfn2pfn_algorithms'):
+                RSEDeterministicTranslation._LFN2PFN_ALGORITHMS.update(module.get_lfn2pfn_algorithms())
+        except (NoOptionError, NoSectionError, ImportError):
+            pass
+
+    def query_policy_packages(self):
+        from rucio.core.vo import list_vos
+        try:
+            multivo = config.config_get_bool('common', 'multi_vo')
+        except (NoOptionError, NoSectionError):
+            multivo = False
+        if not multivo:
+            # single policy package
+            self.try_importing_policy()
+        else:
+            # policy package per VO
+            vos = list_vos()
+            for vo in vos:
+                self.try_importing_policy(vo)
+
     def path(self, scope, name):
         """ Transforms the logical file name into a PFN's path.
 
@@ -249,8 +277,10 @@ class RSEDeterministicTranslation(object):
 
             :returns: RSE specific URI of the physical file
         """
-        # ensure that policy package is loaded in case it registers algorithms
-        import rucio.common.schema  # noqa: F401
+        # on first call, register any lfn2pfn algorithms from the policy package(s) (server only)
+        if getattr(rsemanager, 'SERVER_MODE', None) and not self.loaded_policy_modules:
+            self.query_policy_packages()
+            self.loaded_policy_modules = True
 
         algorithm = self.rse_attributes.get('lfn2pfn_algorithm', 'default')
         if algorithm == 'default':
