@@ -38,8 +38,8 @@ logging.getLogger('boto').setLevel(logging.INFO)
 class Default(protocol.RSEProtocol):
     """ Implementing access to RSEs using the S3 protocol."""
 
-    def __init__(self, protocol_attr, rse_settings):
-        super(Default, self).__init__(protocol_attr, rse_settings)
+    def __init__(self, protocol_attr, rse_settings, logger=None):
+        super(Default, self).__init__(protocol_attr, rse_settings, logger=logger)
         if 'determinism_type' in self.attributes:
             self.attributes['determinism_type'] = 's3'
         self.__conn = None
